# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class Redemption(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'amount': 'Currency',
        'destination_bank_info': 'BankInfo',
        'status': 'dict(str, str)',
        'id': 'str',
        'created_at': 'Timestamp',
        'updated_at': 'Timestamp',
        'paya_tracking_code': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'destination_bank_info': 'destinationBankInfo',
        'status': 'status',
        'id': 'id',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'paya_tracking_code': 'payaTrackingCode'
    }

    def __init__(self, amount=None, destination_bank_info=None, status=None, id=None, created_at=None, updated_at=None, paya_tracking_code=None, local_vars_configuration=None):  # noqa: E501
        """Redemption - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._amount = None
        self._destination_bank_info = None
        self._status = None
        self._id = None
        self._created_at = None
        self._updated_at = None
        self._paya_tracking_code = None
        self.discriminator = None

        self.amount = amount
        self.destination_bank_info = destination_bank_info
        self.status = status
        self.id = id
        self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if paya_tracking_code is not None:
            self.paya_tracking_code = paya_tracking_code

    @property
    def amount(self):
        """Gets the amount of this Redemption.  # noqa: E501


        :return: The amount of this Redemption.  # noqa: E501
        :rtype: Currency
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Redemption.


        :param amount: The amount of this Redemption.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def destination_bank_info(self):
        """Gets the destination_bank_info of this Redemption.  # noqa: E501


        :return: The destination_bank_info of this Redemption.  # noqa: E501
        :rtype: BankInfo
        """
        return self._destination_bank_info

    @destination_bank_info.setter
    def destination_bank_info(self, destination_bank_info):
        """Sets the destination_bank_info of this Redemption.


        :param destination_bank_info: The destination_bank_info of this Redemption.  # noqa: E501
        :type: BankInfo
        """
        if self.local_vars_configuration.client_side_validation and destination_bank_info is None:  # noqa: E501
            raise ValueError("Invalid value for `destination_bank_info`, must not be `None`")  # noqa: E501

        self._destination_bank_info = destination_bank_info

    @property
    def status(self):
        """Gets the status of this Redemption.  # noqa: E501


        :return: The status of this Redemption.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Redemption.


        :param status: The status of this Redemption.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def id(self):
        """Gets the id of this Redemption.  # noqa: E501

        The ID of the redemption request  # noqa: E501

        :return: The id of this Redemption.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Redemption.

        The ID of the redemption request  # noqa: E501

        :param id: The id of this Redemption.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Redemption.  # noqa: E501


        :return: The created_at of this Redemption.  # noqa: E501
        :rtype: Timestamp
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Redemption.


        :param created_at: The created_at of this Redemption.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Redemption.  # noqa: E501


        :return: The updated_at of this Redemption.  # noqa: E501
        :rtype: Timestamp
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Redemption.


        :param updated_at: The updated_at of this Redemption.  # noqa: E501
        :type: Timestamp
        """

        self._updated_at = updated_at

    @property
    def paya_tracking_code(self):
        """Gets the paya_tracking_code of this Redemption.  # noqa: E501

        The Paya tracking code  # noqa: E501

        :return: The paya_tracking_code of this Redemption.  # noqa: E501
        :rtype: str
        """
        return self._paya_tracking_code

    @paya_tracking_code.setter
    def paya_tracking_code(self, paya_tracking_code):
        """Sets the paya_tracking_code of this Redemption.

        The Paya tracking code  # noqa: E501

        :param paya_tracking_code: The paya_tracking_code of this Redemption.  # noqa: E501
        :type: str
        """

        self._paya_tracking_code = paya_tracking_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Redemption):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Redemption):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class WithdrawRequestPreview(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'address': 'str',
        'network': 'Network',
        'symbol': 'Symbol',
        'amount': 'Currency',
        'fee': 'Currency',
        'balance_after_withdraw': 'Currency'
    }

    attribute_map = {
        'address': 'address',
        'network': 'network',
        'symbol': 'symbol',
        'amount': 'amount',
        'fee': 'fee',
        'balance_after_withdraw': 'balanceAfterWithdraw'
    }

    def __init__(self, address=None, network=None, symbol=None, amount=None, fee=None, balance_after_withdraw=None, local_vars_configuration=None):  # noqa: E501
        """WithdrawRequestPreview - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._address = None
        self._network = None
        self._symbol = None
        self._amount = None
        self._fee = None
        self._balance_after_withdraw = None
        self.discriminator = None

        self.address = address
        self.network = network
        self.symbol = symbol
        self.amount = amount
        self.fee = fee
        self.balance_after_withdraw = balance_after_withdraw

    @property
    def address(self):
        """Gets the address of this WithdrawRequestPreview.  # noqa: E501

        Withdrawal address  # noqa: E501

        :return: The address of this WithdrawRequestPreview.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this WithdrawRequestPreview.

        Withdrawal address  # noqa: E501

        :param address: The address of this WithdrawRequestPreview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address is None:  # noqa: E501
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def network(self):
        """Gets the network of this WithdrawRequestPreview.  # noqa: E501


        :return: The network of this WithdrawRequestPreview.  # noqa: E501
        :rtype: Network
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this WithdrawRequestPreview.


        :param network: The network of this WithdrawRequestPreview.  # noqa: E501
        :type: Network
        """
        if self.local_vars_configuration.client_side_validation and network is None:  # noqa: E501
            raise ValueError("Invalid value for `network`, must not be `None`")  # noqa: E501

        self._network = network

    @property
    def symbol(self):
        """Gets the symbol of this WithdrawRequestPreview.  # noqa: E501


        :return: The symbol of this WithdrawRequestPreview.  # noqa: E501
        :rtype: Symbol
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this WithdrawRequestPreview.


        :param symbol: The symbol of this WithdrawRequestPreview.  # noqa: E501
        :type: Symbol
        """
        if self.local_vars_configuration.client_side_validation and symbol is None:  # noqa: E501
            raise ValueError("Invalid value for `symbol`, must not be `None`")  # noqa: E501

        self._symbol = symbol

    @property
    def amount(self):
        """Gets the amount of this WithdrawRequestPreview.  # noqa: E501


        :return: The amount of this WithdrawRequestPreview.  # noqa: E501
        :rtype: Currency
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this WithdrawRequestPreview.


        :param amount: The amount of this WithdrawRequestPreview.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def fee(self):
        """Gets the fee of this WithdrawRequestPreview.  # noqa: E501


        :return: The fee of this WithdrawRequestPreview.  # noqa: E501
        :rtype: Currency
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this WithdrawRequestPreview.


        :param fee: The fee of this WithdrawRequestPreview.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and fee is None:  # noqa: E501
            raise ValueError("Invalid value for `fee`, must not be `None`")  # noqa: E501

        self._fee = fee

    @property
    def balance_after_withdraw(self):
        """Gets the balance_after_withdraw of this WithdrawRequestPreview.  # noqa: E501


        :return: The balance_after_withdraw of this WithdrawRequestPreview.  # noqa: E501
        :rtype: Currency
        """
        return self._balance_after_withdraw

    @balance_after_withdraw.setter
    def balance_after_withdraw(self, balance_after_withdraw):
        """Sets the balance_after_withdraw of this WithdrawRequestPreview.


        :param balance_after_withdraw: The balance_after_withdraw of this WithdrawRequestPreview.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and balance_after_withdraw is None:  # noqa: E501
            raise ValueError("Invalid value for `balance_after_withdraw`, must not be `None`")  # noqa: E501

        self._balance_after_withdraw = balance_after_withdraw

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WithdrawRequestPreview):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WithdrawRequestPreview):
            return True

        return self.to_dict() != other.to_dict()



"""
Zarban API
~~~~~~~~~~~~~

API for Zarban Wallet and services.

:copyright: (c) 2024 by Zarban.
:license: MIT, see LICENSE for more details.
"""

from .service import openapi_client as service_api 
from .wallet import openapi_client as wallet_api

__all__ = ["service_api", "wallet_api"]


# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.account import Account  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestAccount(unittest.TestCase):
    """Account unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Account
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.account.Account()  # noqa: E501
        if include_optional :
            return Account(
                points = 100, 
                address = '0x1234567890123456789012345678901234567890', 
                wallet_balance = zarban.service.openapi_client.models.wallet_balance.WalletBalance(
                    balances = [
                        zarban.service.openapi_client.models.balance.Balance(
                            token = zarban.service.openapi_client.models.token.Token(
                                name = 'Zar Stablecoin', 
                                symbol = 'USD', 
                                decimals = 18, 
                                address = '0x1234567890123456789012345678901234567890', 
                                logo_uri = '/assets/logos/dai.svg', 
                                chain_id = 1, 
                                persian_name = 'زر', ), 
                            balance = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, )
                        ], ), 
                net_worth = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                total_deposits = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                lendingpool_summary = zarban.service.openapi_client.models.account_lendingpool_summary.AccountLendingpoolSummary(
                    total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    total_deposits = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    total_collateral = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    health_factor = '1.5', 
                    net_apy = '0.12', 
                    total_supply_apy = '0.12', 
                    total_borrow_apy = '0.12', 
                    available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    borrow_power_used = '0.30', 
                    current_liquidation_threshold = '0.30', 
                    loan_to_value = '0.30', ), 
                stabelcoin_system_summary = zarban.service.openapi_client.models.account_stablecoin_system_summary.AccountStablecoinSystemSummary(
                    total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    total_deposits = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    net_apy = '0.30', ), 
                staking_summary = zarban.service.openapi_client.models.account_staking_summary.AccountStakingSummary(
                    total_stake = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    unclaimed_reward = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    net_apy = '0.30', )
            )
        else :
            return Account(
                points = 100,
                address = '0x1234567890123456789012345678901234567890',
                wallet_balance = zarban.service.openapi_client.models.wallet_balance.WalletBalance(
                    balances = [
                        zarban.service.openapi_client.models.balance.Balance(
                            token = zarban.service.openapi_client.models.token.Token(
                                name = 'Zar Stablecoin', 
                                symbol = 'USD', 
                                decimals = 18, 
                                address = '0x1234567890123456789012345678901234567890', 
                                logo_uri = '/assets/logos/dai.svg', 
                                chain_id = 1, 
                                persian_name = 'زر', ), 
                            balance = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, )
                        ], ),
                net_worth = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                total_deposits = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                lendingpool_summary = zarban.service.openapi_client.models.account_lendingpool_summary.AccountLendingpoolSummary(
                    total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    total_deposits = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    total_collateral = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    health_factor = '1.5', 
                    net_apy = '0.12', 
                    total_supply_apy = '0.12', 
                    total_borrow_apy = '0.12', 
                    available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    borrow_power_used = '0.30', 
                    current_liquidation_threshold = '0.30', 
                    loan_to_value = '0.30', ),
                stabelcoin_system_summary = zarban.service.openapi_client.models.account_stablecoin_system_summary.AccountStablecoinSystemSummary(
                    total_debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    total_deposits = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    net_apy = '0.30', ),
                staking_summary = zarban.service.openapi_client.models.account_staking_summary.AccountStakingSummary(
                    total_stake = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    unclaimed_reward = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                    net_apy = '0.30', ),
        )

    def testAccount(self):
        """Test Account"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.quote_response import QuoteResponse  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestQuoteResponse(unittest.TestCase):
    """QuoteResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test QuoteResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.quote_response.QuoteResponse()  # noqa: E501
        if include_optional :
            return QuoteResponse(
                type = 'Classic', 
                trade_type = 'ExactInput', 
                time = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                quote = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                quote_id = '0', 
                gas_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                gas_use_estimate = 56, 
                gas_fee_estimate = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                route_string = 'A -- [0x0000000000000000000000000000000000000012] --> B -- [0x0000000000000000000000000000000000000023] --> C', 
                method_parameters = zarban.service.openapi_client.models.method_parameters.MethodParameters(
                    to = 'a', 
                    calldata = '0', 
                    value = '0', ), 
                route = [
                    null
                    ], 
                order_info = zarban.service.openapi_client.models.order_info.OrderInfo(
                    chain_id = 56, 
                    permit2_address = 'a', 
                    reactor = 'a', 
                    swapper = 'a', 
                    nonce = '0', 
                    deadline = zarban.service.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    additional_validation_contract = 'a', 
                    additional_validation_data = 'a', 
                    decay_start_time = zarban.service.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    decay_end_time = zarban.service.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    exclusive_filler = 'a', 
                    exclusivity_override_bps = 56, 
                    input = zarban.service.openapi_client.models.dutch_amount.DutchAmount(
                        token = zarban.service.openapi_client.models.token.Token(
                            name = 'Zar Stablecoin', 
                            symbol = 'USD', 
                            decimals = 18, 
                            address = '0x1234567890123456789012345678901234567890', 
                            logo_uri = '/assets/logos/dai.svg', 
                            chain_id = 1, 
                            persian_name = 'زر', ), 
                        start_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        end_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        recipient = 'a', ), 
                    outputs = [
                        zarban.service.openapi_client.models.dutch_amount.DutchAmount(
                            token = zarban.service.openapi_client.models.token.Token(
                                name = 'Zar Stablecoin', 
                                symbol = 'USD', 
                                decimals = 18, 
                                address = '0x1234567890123456789012345678901234567890', 
                                logo_uri = '/assets/logos/dai.svg', 
                                chain_id = 1, 
                                persian_name = 'زر', ), 
                            start_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            end_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            recipient = 'a', )
                        ], ), 
                encoded_order = 'a', 
                order_hash = 'a', 
                permit_data = zarban.service.openapi_client.models.typed_data.TypedData(
                    types = {
                        'key' : [
                            zarban.service.openapi_client.models.type.Type(
                                name = '0', 
                                type = '0', )
                            ]
                        }, 
                    primary_type = '0', 
                    domain = zarban.service.openapi_client.models.typed_data_domain.TypedDataDomain(
                        name = '0', 
                        version = '0', 
                        chain_id = '0', 
                        verifying_contract = '0', 
                        salt = '0', ), 
                    message = { }, )
            )
        else :
            return QuoteResponse(
                type = 'Classic',
                trade_type = 'ExactInput',
                time = zarban.service.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
                amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                quote = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                quote_id = '0',
                gas_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                gas_use_estimate = 56,
                gas_fee_estimate = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                route_string = 'A -- [0x0000000000000000000000000000000000000012] --> B -- [0x0000000000000000000000000000000000000023] --> C',
                route = [
                    null
                    ],
        )

    def testQuoteResponse(self):
        """Test QuoteResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.transaction_response import TransactionResponse  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestTransactionResponse(unittest.TestCase):
    """TransactionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TransactionResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.transaction_response.TransactionResponse()  # noqa: E501
        if include_optional :
            return TransactionResponse(
                data = [
                    zarban.wallet.openapi_client.models.transaction.Transaction(
                        id = 56, 
                        time = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        type = 'Credit', 
                        from = '0', 
                        to = '0', 
                        symbol = 'USD', 
                        amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        direction = 'Inbound', 
                        external_transaction = zarban.wallet.openapi_client.models.external_transaction.ExternalTransaction(
                            id = 56, 
                            time = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                                jalaali = '1399-01-01T00:00:00Z', 
                                gregorian = '2020-01-01T00:00:00Z', ), 
                            type = 'Credit', 
                            hash = '0', 
                            from = '0', 
                            to = '0', 
                            comment = '0', 
                            amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            symbol = 'USD', 
                            network = zarban.wallet.openapi_client.models.network.Network(
                                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                logo_uri = '0', ), 
                            status = 'Sent', ), )
                    ]
            )
        else :
            return TransactionResponse(
                data = [
                    zarban.wallet.openapi_client.models.transaction.Transaction(
                        id = 56, 
                        time = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        type = 'Credit', 
                        from = '0', 
                        to = '0', 
                        symbol = 'USD', 
                        amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        direction = 'Inbound', 
                        external_transaction = zarban.wallet.openapi_client.models.external_transaction.ExternalTransaction(
                            id = 56, 
                            time = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                                jalaali = '1399-01-01T00:00:00Z', 
                                gregorian = '2020-01-01T00:00:00Z', ), 
                            type = 'Credit', 
                            hash = '0', 
                            from = '0', 
                            to = '0', 
                            comment = '0', 
                            amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            symbol = 'USD', 
                            network = zarban.wallet.openapi_client.models.network.Network(
                                name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                logo_uri = '0', ), 
                            status = 'Sent', ), )
                    ],
        )

    def testTransactionResponse(self):
        """Test TransactionResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.withdraw_request_response import WithdrawRequestResponse  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestWithdrawRequestResponse(unittest.TestCase):
    """WithdrawRequestResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WithdrawRequestResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.withdraw_request_response.WithdrawRequestResponse()  # noqa: E501
        if include_optional :
            return WithdrawRequestResponse(
                data = [
                    zarban.wallet.openapi_client.models.withdraw_request.WithdrawRequest(
                        id = 56, 
                        time_created = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        network = zarban.wallet.openapi_client.models.network.Network(
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', ), 
                        symbol = 'USD', 
                        amount = '0', 
                        to = '0', 
                        comment = '0', 
                        status = 'Pending', 
                        block_explorer_url = 'https://etherscan.io/tx/0x1234567890abcdef', )
                    ]
            )
        else :
            return WithdrawRequestResponse(
                data = [
                    zarban.wallet.openapi_client.models.withdraw_request.WithdrawRequest(
                        id = 56, 
                        time_created = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                            jalaali = '1399-01-01T00:00:00Z', 
                            gregorian = '2020-01-01T00:00:00Z', ), 
                        network = zarban.wallet.openapi_client.models.network.Network(
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', ), 
                        symbol = 'USD', 
                        amount = '0', 
                        to = '0', 
                        comment = '0', 
                        status = 'Pending', 
                        block_explorer_url = 'https://etherscan.io/tx/0x1234567890abcdef', )
                    ],
        )

    def testWithdrawRequestResponse(self):
        """Test WithdrawRequestResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.transaction import Transaction  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestTransaction(unittest.TestCase):
    """Transaction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Transaction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.transaction.Transaction()  # noqa: E501
        if include_optional :
            return Transaction(
                id = 56, 
                time = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ), 
                type = 'Credit', 
                _from = '0', 
                to = '0', 
                symbol = 'USD', 
                amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                direction = 'Inbound', 
                external_transaction = zarban.wallet.openapi_client.models.external_transaction.ExternalTransaction(
                    id = 56, 
                    time = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                        jalaali = '1399-01-01T00:00:00Z', 
                        gregorian = '2020-01-01T00:00:00Z', ), 
                    type = 'Credit', 
                    hash = '0', 
                    from = '0', 
                    to = '0', 
                    comment = '0', 
                    amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                    symbol = 'USD', 
                    network = zarban.wallet.openapi_client.models.network.Network(
                        name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        logo_uri = '0', ), 
                    status = 'Sent', )
            )
        else :
            return Transaction(
                id = 56,
                time = zarban.wallet.openapi_client.models.timestamp.Timestamp(
                    jalaali = '1399-01-01T00:00:00Z', 
                    gregorian = '2020-01-01T00:00:00Z', ),
                type = 'Credit',
                _from = '0',
                to = '0',
                symbol = 'USD',
                amount = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}},
                direction = 'Inbound',
        )

    def testTransaction(self):
        """Test Transaction"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class Task(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'description': 'str',
        'points': 'int',
        'status': 'str',
        'completed_at': 'Timestamp'
    }

    attribute_map = {
        'id': 'id',
        'description': 'description',
        'points': 'points',
        'status': 'status',
        'completed_at': 'completedAt'
    }

    def __init__(self, id=None, description=None, points=None, status=None, completed_at=None, local_vars_configuration=None):  # noqa: E501
        """Task - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._description = None
        self._points = None
        self._status = None
        self._completed_at = None
        self.discriminator = None

        self.id = id
        self.description = description
        self.points = points
        self.status = status
        if completed_at is not None:
            self.completed_at = completed_at

    @property
    def id(self):
        """Gets the id of this Task.  # noqa: E501

        Task ID  # noqa: E501

        :return: The id of this Task.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Task.

        Task ID  # noqa: E501

        :param id: The id of this Task.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def description(self):
        """Gets the description of this Task.  # noqa: E501

        Task description  # noqa: E501

        :return: The description of this Task.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Task.

        Task description  # noqa: E501

        :param description: The description of this Task.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def points(self):
        """Gets the points of this Task.  # noqa: E501

        Task reward  # noqa: E501

        :return: The points of this Task.  # noqa: E501
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this Task.

        Task reward  # noqa: E501

        :param points: The points of this Task.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and points is None:  # noqa: E501
            raise ValueError("Invalid value for `points`, must not be `None`")  # noqa: E501

        self._points = points

    @property
    def status(self):
        """Gets the status of this Task.  # noqa: E501

        Task status. Possible values \"Pending\", \"Completed\"  # noqa: E501

        :return: The status of this Task.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Task.

        Task status. Possible values \"Pending\", \"Completed\"  # noqa: E501

        :param status: The status of this Task.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def completed_at(self):
        """Gets the completed_at of this Task.  # noqa: E501


        :return: The completed_at of this Task.  # noqa: E501
        :rtype: Timestamp
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this Task.


        :param completed_at: The completed_at of this Task.  # noqa: E501
        :type: Timestamp
        """

        self._completed_at = completed_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Task):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Task):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.update_phone_request import UpdatePhoneRequest  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestUpdatePhoneRequest(unittest.TestCase):
    """UpdatePhoneRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpdatePhoneRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.update_phone_request.UpdatePhoneRequest()  # noqa: E501
        if include_optional :
            return UpdatePhoneRequest(
                number = '09123456789'
            )
        else :
            return UpdatePhoneRequest(
                number = '09123456789',
        )

    def testUpdatePhoneRequest(self):
        """Test UpdatePhoneRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from zarban.service.openapi_client.api.accounts_api import AccountsApi
from zarban.service.openapi_client.api.addresses_api import AddressesApi
from zarban.service.openapi_client.api.borrows_api import BorrowsApi
from zarban.service.openapi_client.api.collector_api import CollectorApi
from zarban.service.openapi_client.api.deposits_api import DepositsApi
from zarban.service.openapi_client.api.ilks_api import IlksApi
from zarban.service.openapi_client.api.lending_pool_api import LendingPoolApi
from zarban.service.openapi_client.api.logs_api import LogsApi
from zarban.service.openapi_client.api.orders_api import OrdersApi
from zarban.service.openapi_client.api.permit_api import PermitApi
from zarban.service.openapi_client.api.points_api import PointsApi
from zarban.service.openapi_client.api.prices_api import PricesApi
from zarban.service.openapi_client.api.stable_coin_system_api import StableCoinSystemApi
from zarban.service.openapi_client.api.staking_api import StakingApi
from zarban.service.openapi_client.api.swap_api import SwapApi
from zarban.service.openapi_client.api.vaults_api import VaultsApi
from zarban.service.openapi_client.api.websocket_api import WebsocketApi



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from zarban.service.openapi_client.api_client import ApiClient
from zarban.service.openapi_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class StakingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def collect_staking_reward(self, staking_collect_reward_tx_request, **kwargs):  # noqa: E501
        """Collect staking reward  # noqa: E501

        Collect staking reward  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collect_staking_reward(staking_collect_reward_tx_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StakingCollectRewardTxRequest staking_collect_reward_tx_request: Collect reward transaction request (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StakingCollectRewardTxResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.collect_staking_reward_with_http_info(staking_collect_reward_tx_request, **kwargs)  # noqa: E501

    def collect_staking_reward_with_http_info(self, staking_collect_reward_tx_request, **kwargs):  # noqa: E501
        """Collect staking reward  # noqa: E501

        Collect staking reward  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collect_staking_reward_with_http_info(staking_collect_reward_tx_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StakingCollectRewardTxRequest staking_collect_reward_tx_request: Collect reward transaction request (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StakingCollectRewardTxResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'staking_collect_reward_tx_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method collect_staking_reward" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'staking_collect_reward_tx_request' is set
        if self.api_client.client_side_validation and ('staking_collect_reward_tx_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['staking_collect_reward_tx_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `staking_collect_reward_tx_request` when calling `collect_staking_reward`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'staking_collect_reward_tx_request' in local_var_params:
            body_params = local_var_params['staking_collect_reward_tx_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/staking/tx/collectreward', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StakingCollectRewardTxResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_staking_plans(self, **kwargs):  # noqa: E501
        """Get staking plans  # noqa: E501

        Get staking plans  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_staking_plans(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StakePlansResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_staking_plans_with_http_info(**kwargs)  # noqa: E501

    def get_staking_plans_with_http_info(self, **kwargs):  # noqa: E501
        """Get staking plans  # noqa: E501

        Get staking plans  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_staking_plans_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StakePlansResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_staking_plans" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/staking/plans', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StakePlansResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_staking_stats(self, **kwargs):  # noqa: E501
        """Get user staking stats  # noqa: E501

        Get user staking stats  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_staking_stats(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user: Ethereum address of the user
        :param str address: Ethereum address of the staking contract
        :param bool active: Filter by active stakes
        :param int cursor: Cursor for pagination
        :param int limit: Limit the number of stakes returned (default is 50)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UserStakesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_user_staking_stats_with_http_info(**kwargs)  # noqa: E501

    def get_user_staking_stats_with_http_info(self, **kwargs):  # noqa: E501
        """Get user staking stats  # noqa: E501

        Get user staking stats  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_staking_stats_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user: Ethereum address of the user
        :param str address: Ethereum address of the staking contract
        :param bool active: Filter by active stakes
        :param int cursor: Cursor for pagination
        :param int limit: Limit the number of stakes returned (default is 50)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UserStakesResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'user',
            'address',
            'active',
            'cursor',
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_staking_stats" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'user' in local_var_params and not re.search(r'0x[a-fA-F0-9]{40}', local_var_params['user']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `user` when calling `get_user_staking_stats`, must conform to the pattern `/0x[a-fA-F0-9]{40}/`")  # noqa: E501
        if self.api_client.client_side_validation and 'address' in local_var_params and not re.search(r'0x[a-fA-F0-9]{40}', local_var_params['address']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `address` when calling `get_user_staking_stats`, must conform to the pattern `/0x[a-fA-F0-9]{40}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user' in local_var_params and local_var_params['user'] is not None:  # noqa: E501
            query_params.append(('user', local_var_params['user']))  # noqa: E501
        if 'address' in local_var_params and local_var_params['address'] is not None:  # noqa: E501
            query_params.append(('address', local_var_params['address']))  # noqa: E501
        if 'active' in local_var_params and local_var_params['active'] is not None:  # noqa: E501
            query_params.append(('active', local_var_params['active']))  # noqa: E501
        if 'cursor' in local_var_params and local_var_params['cursor'] is not None:  # noqa: E501
            query_params.append(('cursor', local_var_params['cursor']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/staking/stats', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserStakesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stake_to_staking_contract(self, staking_stake_tx_request, **kwargs):  # noqa: E501
        """Stake to staking contract  # noqa: E501

        Stake to staking contract  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stake_to_staking_contract(staking_stake_tx_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StakingStakeTxRequest staking_stake_tx_request: Stake transaction request, if amount is not provided, then the whole wallet balance will be used (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StakingStakeTxResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.stake_to_staking_contract_with_http_info(staking_stake_tx_request, **kwargs)  # noqa: E501

    def stake_to_staking_contract_with_http_info(self, staking_stake_tx_request, **kwargs):  # noqa: E501
        """Stake to staking contract  # noqa: E501

        Stake to staking contract  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stake_to_staking_contract_with_http_info(staking_stake_tx_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StakingStakeTxRequest staking_stake_tx_request: Stake transaction request, if amount is not provided, then the whole wallet balance will be used (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StakingStakeTxResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'staking_stake_tx_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stake_to_staking_contract" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'staking_stake_tx_request' is set
        if self.api_client.client_side_validation and ('staking_stake_tx_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['staking_stake_tx_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `staking_stake_tx_request` when calling `stake_to_staking_contract`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'staking_stake_tx_request' in local_var_params:
            body_params = local_var_params['staking_stake_tx_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/staking/tx/stake', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StakingStakeTxResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def withdraw_staked_asset(self, staking_withdraw_tx_request, **kwargs):  # noqa: E501
        """Withdraw staked asset  # noqa: E501

        Withdraw staked asset  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.withdraw_staked_asset(staking_withdraw_tx_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StakingWithdrawTxRequest staking_withdraw_tx_request: Withdraw transaction request, if amount is not provided, then the whole staked amount will be withdrawn (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StakingWithdrawTxResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.withdraw_staked_asset_with_http_info(staking_withdraw_tx_request, **kwargs)  # noqa: E501

    def withdraw_staked_asset_with_http_info(self, staking_withdraw_tx_request, **kwargs):  # noqa: E501
        """Withdraw staked asset  # noqa: E501

        Withdraw staked asset  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.withdraw_staked_asset_with_http_info(staking_withdraw_tx_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StakingWithdrawTxRequest staking_withdraw_tx_request: Withdraw transaction request, if amount is not provided, then the whole staked amount will be withdrawn (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StakingWithdrawTxResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'staking_withdraw_tx_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method withdraw_staked_asset" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'staking_withdraw_tx_request' is set
        if self.api_client.client_side_validation and ('staking_withdraw_tx_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['staking_withdraw_tx_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `staking_withdraw_tx_request` when calling `withdraw_staked_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'staking_withdraw_tx_request' in local_var_params:
            body_params = local_var_params['staking_withdraw_tx_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/staking/tx/withdraw', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StakingWithdrawTxResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.service.openapi_client
from zarban.service.openapi_client.api.staking_api import StakingApi  # noqa: E501
from zarban.service.openapi_client.rest import ApiException


class TestStakingApi(unittest.TestCase):
    """StakingApi unit test stubs"""

    def setUp(self):
        self.api = zarban.service.openapi_client.api.staking_api.StakingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_collect_staking_reward(self):
        """Test case for collect_staking_reward

        Collect staking reward  # noqa: E501
        """
        pass

    def test_get_staking_plans(self):
        """Test case for get_staking_plans

        Get staking plans  # noqa: E501
        """
        pass

    def test_get_user_staking_stats(self):
        """Test case for get_user_staking_stats

        Get user staking stats  # noqa: E501
        """
        pass

    def test_stake_to_staking_contract(self):
        """Test case for stake_to_staking_contract

        Stake to staking contract  # noqa: E501
        """
        pass

    def test_withdraw_staked_asset(self):
        """Test case for withdraw_staked_asset

        Withdraw staked asset  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.vaults_response import VaultsResponse  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestVaultsResponse(unittest.TestCase):
    """VaultsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VaultsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.vaults_response.VaultsResponse()  # noqa: E501
        if include_optional :
            return VaultsResponse(
                data = [
                    zarban.service.openapi_client.models.vault.Vault(
                        id = 1, 
                        owner = '0x1234567890123456789012345678901234567890', 
                        urn = '0x1234567890123456789012345678901234567890', 
                        liquidation_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        collateral_locked = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        collateralization_ratio = '1.5', 
                        loan_to_value = '0.5', 
                        debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        available_to_withdraw = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        available_to_mint = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        ilk = zarban.service.openapi_client.models.ilk.Ilk(
                            name = '0', 
                            symbol = 'USD', 
                            minimum_collateralization_ratio = '0', 
                            maximum_loan_to_value = '0', 
                            liquidation_penalty = '0', 
                            debt_ceiling = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            annual_stability_fee = '0', 
                            dust_limit = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            next_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            join = '0', 
                            median = '0', 
                            gem = '0', 
                            clipper = '0', 
                            pip = '0', 
                            hole = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            dirt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, ), )
                    ]
            )
        else :
            return VaultsResponse(
                data = [
                    zarban.service.openapi_client.models.vault.Vault(
                        id = 1, 
                        owner = '0x1234567890123456789012345678901234567890', 
                        urn = '0x1234567890123456789012345678901234567890', 
                        liquidation_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        collateral_locked = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        collateralization_ratio = '1.5', 
                        loan_to_value = '0.5', 
                        debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        available_to_withdraw = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        available_to_mint = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        ilk = zarban.service.openapi_client.models.ilk.Ilk(
                            name = '0', 
                            symbol = 'USD', 
                            minimum_collateralization_ratio = '0', 
                            maximum_loan_to_value = '0', 
                            liquidation_penalty = '0', 
                            debt_ceiling = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            annual_stability_fee = '0', 
                            dust_limit = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            next_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            join = '0', 
                            median = '0', 
                            gem = '0', 
                            clipper = '0', 
                            pip = '0', 
                            hole = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            dirt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                            available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, ), )
                    ],
        )

    def testVaultsResponse(self):
        """Test VaultsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.wallet_balance import WalletBalance  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestWalletBalance(unittest.TestCase):
    """WalletBalance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WalletBalance
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.wallet_balance.WalletBalance()  # noqa: E501
        if include_optional :
            return WalletBalance(
                total = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                balances = [
                    zarban.wallet.openapi_client.models.balance.Balance(
                        locked = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        coin = zarban.wallet.openapi_client.models.coin.Coin(
                            config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                                is_tradeable = True, 
                                withdraw_fees = {"tron":"10"}, 
                                min_withdrawal = {"tron":"10"}, 
                                needs_memo = True, ), 
                            symbol = 'USD', 
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', 
                            depositable_networks = [
                                zarban.wallet.openapi_client.models.network.Network(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', )
                                ], 
                            withdrawable_networks = [
                                zarban.wallet.openapi_client.models.network.Network(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', )
                                ], 
                            content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                                title = '0', 
                                text = '0', 
                                bullets = [
                                    '0'
                                    ], ), ), 
                        balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, )
                    ]
            )
        else :
            return WalletBalance(
                total = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}},
                balances = [
                    zarban.wallet.openapi_client.models.balance.Balance(
                        locked = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        coin = zarban.wallet.openapi_client.models.coin.Coin(
                            config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                                is_tradeable = True, 
                                withdraw_fees = {"tron":"10"}, 
                                min_withdrawal = {"tron":"10"}, 
                                needs_memo = True, ), 
                            symbol = 'USD', 
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', 
                            depositable_networks = [
                                zarban.wallet.openapi_client.models.network.Network(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', )
                                ], 
                            withdrawable_networks = [
                                zarban.wallet.openapi_client.models.network.Network(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', )
                                ], 
                            content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                                title = '0', 
                                text = '0', 
                                bullets = [
                                    '0'
                                    ], ), ), 
                        balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, )
                    ],
        )

    def testWalletBalance(self):
        """Test WalletBalance"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class ChainActivityStepData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'label': 'dict(str, str)',
        'gas_use_estimate': 'int',
        'gas_fee_estimate': 'dict(str, str)',
        'method_parameters': 'MethodParameters',
        'name': 'str',
        'typed_data': 'TypedData',
        'hash': 'str',
        'message': 'str'
    }

    attribute_map = {
        'type': 'type',
        'label': 'label',
        'gas_use_estimate': 'gasUseEstimate',
        'gas_fee_estimate': 'gasFeeEstimate',
        'method_parameters': 'methodParameters',
        'name': 'name',
        'typed_data': 'typedData',
        'hash': 'hash',
        'message': 'message'
    }

    def __init__(self, type=None, label=None, gas_use_estimate=None, gas_fee_estimate=None, method_parameters=None, name=None, typed_data=None, hash=None, message=None, local_vars_configuration=None):  # noqa: E501
        """ChainActivityStepData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._label = None
        self._gas_use_estimate = None
        self._gas_fee_estimate = None
        self._method_parameters = None
        self._name = None
        self._typed_data = None
        self._hash = None
        self._message = None
        self.discriminator = None

        self.type = type
        self.label = label
        self.gas_use_estimate = gas_use_estimate
        self.gas_fee_estimate = gas_fee_estimate
        self.method_parameters = method_parameters
        self.name = name
        self.typed_data = typed_data
        self.hash = hash
        self.message = message

    @property
    def type(self):
        """Gets the type of this ChainActivityStepData.  # noqa: E501


        :return: The type of this ChainActivityStepData.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ChainActivityStepData.


        :param type: The type of this ChainActivityStepData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def label(self):
        """Gets the label of this ChainActivityStepData.  # noqa: E501


        :return: The label of this ChainActivityStepData.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this ChainActivityStepData.


        :param label: The label of this ChainActivityStepData.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def gas_use_estimate(self):
        """Gets the gas_use_estimate of this ChainActivityStepData.  # noqa: E501


        :return: The gas_use_estimate of this ChainActivityStepData.  # noqa: E501
        :rtype: int
        """
        return self._gas_use_estimate

    @gas_use_estimate.setter
    def gas_use_estimate(self, gas_use_estimate):
        """Sets the gas_use_estimate of this ChainActivityStepData.


        :param gas_use_estimate: The gas_use_estimate of this ChainActivityStepData.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and gas_use_estimate is None:  # noqa: E501
            raise ValueError("Invalid value for `gas_use_estimate`, must not be `None`")  # noqa: E501

        self._gas_use_estimate = gas_use_estimate

    @property
    def gas_fee_estimate(self):
        """Gets the gas_fee_estimate of this ChainActivityStepData.  # noqa: E501


        :return: The gas_fee_estimate of this ChainActivityStepData.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._gas_fee_estimate

    @gas_fee_estimate.setter
    def gas_fee_estimate(self, gas_fee_estimate):
        """Sets the gas_fee_estimate of this ChainActivityStepData.


        :param gas_fee_estimate: The gas_fee_estimate of this ChainActivityStepData.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and gas_fee_estimate is None:  # noqa: E501
            raise ValueError("Invalid value for `gas_fee_estimate`, must not be `None`")  # noqa: E501

        self._gas_fee_estimate = gas_fee_estimate

    @property
    def method_parameters(self):
        """Gets the method_parameters of this ChainActivityStepData.  # noqa: E501


        :return: The method_parameters of this ChainActivityStepData.  # noqa: E501
        :rtype: MethodParameters
        """
        return self._method_parameters

    @method_parameters.setter
    def method_parameters(self, method_parameters):
        """Sets the method_parameters of this ChainActivityStepData.


        :param method_parameters: The method_parameters of this ChainActivityStepData.  # noqa: E501
        :type: MethodParameters
        """
        if self.local_vars_configuration.client_side_validation and method_parameters is None:  # noqa: E501
            raise ValueError("Invalid value for `method_parameters`, must not be `None`")  # noqa: E501

        self._method_parameters = method_parameters

    @property
    def name(self):
        """Gets the name of this ChainActivityStepData.  # noqa: E501

        The name of the EIP712 signature  # noqa: E501

        :return: The name of this ChainActivityStepData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChainActivityStepData.

        The name of the EIP712 signature  # noqa: E501

        :param name: The name of this ChainActivityStepData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def typed_data(self):
        """Gets the typed_data of this ChainActivityStepData.  # noqa: E501


        :return: The typed_data of this ChainActivityStepData.  # noqa: E501
        :rtype: TypedData
        """
        return self._typed_data

    @typed_data.setter
    def typed_data(self, typed_data):
        """Sets the typed_data of this ChainActivityStepData.


        :param typed_data: The typed_data of this ChainActivityStepData.  # noqa: E501
        :type: TypedData
        """
        if self.local_vars_configuration.client_side_validation and typed_data is None:  # noqa: E501
            raise ValueError("Invalid value for `typed_data`, must not be `None`")  # noqa: E501

        self._typed_data = typed_data

    @property
    def hash(self):
        """Gets the hash of this ChainActivityStepData.  # noqa: E501

        The hash of the EIP712 signature that needs to be signed  # noqa: E501

        :return: The hash of this ChainActivityStepData.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this ChainActivityStepData.

        The hash of the EIP712 signature that needs to be signed  # noqa: E501

        :param hash: The hash of this ChainActivityStepData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and hash is None:  # noqa: E501
            raise ValueError("Invalid value for `hash`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                hash is not None and not re.search(r'^(0x)?[0-9a-fA-F]{64}$', hash)):  # noqa: E501
            raise ValueError(r"Invalid value for `hash`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{64}$/`")  # noqa: E501

        self._hash = hash

    @property
    def message(self):
        """Gets the message of this ChainActivityStepData.  # noqa: E501

        The message that needs to be signed  # noqa: E501

        :return: The message of this ChainActivityStepData.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ChainActivityStepData.

        The message that needs to be signed  # noqa: E501

        :param message: The message of this ChainActivityStepData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChainActivityStepData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChainActivityStepData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class Transaction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'time': 'Timestamp',
        'type': 'TransactionType',
        '_from': 'str',
        'to': 'str',
        'symbol': 'Symbol',
        'amount': 'Currency',
        'direction': 'str',
        'external_transaction': 'ExternalTransaction'
    }

    attribute_map = {
        'id': 'id',
        'time': 'time',
        'type': 'type',
        '_from': 'from',
        'to': 'to',
        'symbol': 'symbol',
        'amount': 'amount',
        'direction': 'direction',
        'external_transaction': 'externalTransaction'
    }

    def __init__(self, id=None, time=None, type=None, _from=None, to=None, symbol=None, amount=None, direction=None, external_transaction=None, local_vars_configuration=None):  # noqa: E501
        """Transaction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._time = None
        self._type = None
        self.__from = None
        self._to = None
        self._symbol = None
        self._amount = None
        self._direction = None
        self._external_transaction = None
        self.discriminator = None

        self.id = id
        self.time = time
        self.type = type
        self._from = _from
        self.to = to
        self.symbol = symbol
        self.amount = amount
        self.direction = direction
        if external_transaction is not None:
            self.external_transaction = external_transaction

    @property
    def id(self):
        """Gets the id of this Transaction.  # noqa: E501

        Unique identifier of the transaction  # noqa: E501

        :return: The id of this Transaction.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Transaction.

        Unique identifier of the transaction  # noqa: E501

        :param id: The id of this Transaction.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def time(self):
        """Gets the time of this Transaction.  # noqa: E501


        :return: The time of this Transaction.  # noqa: E501
        :rtype: Timestamp
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this Transaction.


        :param time: The time of this Transaction.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and time is None:  # noqa: E501
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    @property
    def type(self):
        """Gets the type of this Transaction.  # noqa: E501


        :return: The type of this Transaction.  # noqa: E501
        :rtype: TransactionType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Transaction.


        :param type: The type of this Transaction.  # noqa: E501
        :type: TransactionType
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def _from(self):
        """Gets the _from of this Transaction.  # noqa: E501

        The ID of the user from whom the transaction originated  # noqa: E501

        :return: The _from of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this Transaction.

        The ID of the user from whom the transaction originated  # noqa: E501

        :param _from: The _from of this Transaction.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and _from is None:  # noqa: E501
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this Transaction.  # noqa: E501

        The ID of the user to whom the transaction is directed  # noqa: E501

        :return: The to of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this Transaction.

        The ID of the user to whom the transaction is directed  # noqa: E501

        :param to: The to of this Transaction.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def symbol(self):
        """Gets the symbol of this Transaction.  # noqa: E501


        :return: The symbol of this Transaction.  # noqa: E501
        :rtype: Symbol
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this Transaction.


        :param symbol: The symbol of this Transaction.  # noqa: E501
        :type: Symbol
        """
        if self.local_vars_configuration.client_side_validation and symbol is None:  # noqa: E501
            raise ValueError("Invalid value for `symbol`, must not be `None`")  # noqa: E501

        self._symbol = symbol

    @property
    def amount(self):
        """Gets the amount of this Transaction.  # noqa: E501


        :return: The amount of this Transaction.  # noqa: E501
        :rtype: Currency
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Transaction.


        :param amount: The amount of this Transaction.  # noqa: E501
        :type: Currency
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def direction(self):
        """Gets the direction of this Transaction.  # noqa: E501

        Equal to \"Inbound\" if the transaction is directed to the user, and \"Outbound\" if the transaction is directed from the user.  # noqa: E501

        :return: The direction of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this Transaction.

        Equal to \"Inbound\" if the transaction is directed to the user, and \"Outbound\" if the transaction is directed from the user.  # noqa: E501

        :param direction: The direction of this Transaction.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and direction is None:  # noqa: E501
            raise ValueError("Invalid value for `direction`, must not be `None`")  # noqa: E501
        allowed_values = ["Inbound", "Outbound"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and direction not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `direction` ({0}), must be one of {1}"  # noqa: E501
                .format(direction, allowed_values)
            )

        self._direction = direction

    @property
    def external_transaction(self):
        """Gets the external_transaction of this Transaction.  # noqa: E501


        :return: The external_transaction of this Transaction.  # noqa: E501
        :rtype: ExternalTransaction
        """
        return self._external_transaction

    @external_transaction.setter
    def external_transaction(self, external_transaction):
        """Sets the external_transaction of this Transaction.


        :param external_transaction: The external_transaction of this Transaction.  # noqa: E501
        :type: ExternalTransaction
        """

        self._external_transaction = external_transaction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transaction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Transaction):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class User(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'username': 'str',
        'phone': 'str',
        'is_email_verified': 'bool',
        'is_phone_verified': 'bool',
        'is_kyc_verified': 'bool',
        'is_child': 'bool',
        'is_super_user': 'bool',
        'is_admin': 'bool',
        'telegram': 'TelegramProfile'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'username': 'username',
        'phone': 'phone',
        'is_email_verified': 'isEmailVerified',
        'is_phone_verified': 'isPhoneVerified',
        'is_kyc_verified': 'isKycVerified',
        'is_child': 'isChild',
        'is_super_user': 'isSuperUser',
        'is_admin': 'isAdmin',
        'telegram': 'telegram'
    }

    def __init__(self, first_name=None, last_name=None, email=None, username=None, phone=None, is_email_verified=None, is_phone_verified=None, is_kyc_verified=None, is_child=None, is_super_user=None, is_admin=None, telegram=None, local_vars_configuration=None):  # noqa: E501
        """User - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._first_name = None
        self._last_name = None
        self._email = None
        self._username = None
        self._phone = None
        self._is_email_verified = None
        self._is_phone_verified = None
        self._is_kyc_verified = None
        self._is_child = None
        self._is_super_user = None
        self._is_admin = None
        self._telegram = None
        self.discriminator = None

        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if username is not None:
            self.username = username
        if phone is not None:
            self.phone = phone
        if is_email_verified is not None:
            self.is_email_verified = is_email_verified
        if is_phone_verified is not None:
            self.is_phone_verified = is_phone_verified
        if is_kyc_verified is not None:
            self.is_kyc_verified = is_kyc_verified
        if is_child is not None:
            self.is_child = is_child
        if is_super_user is not None:
            self.is_super_user = is_super_user
        if is_admin is not None:
            self.is_admin = is_admin
        if telegram is not None:
            self.telegram = telegram

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501

        User's first name  # noqa: E501

        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.

        User's first name  # noqa: E501

        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501

        User's last name  # noqa: E501

        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.

        User's last name  # noqa: E501

        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this User.  # noqa: E501


        :return: The email of this User.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this User.


        :param email: The email of this User.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def username(self):
        """Gets the username of this User.  # noqa: E501


        :return: The username of this User.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this User.


        :param username: The username of this User.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def phone(self):
        """Gets the phone of this User.  # noqa: E501


        :return: The phone of this User.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this User.


        :param phone: The phone of this User.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def is_email_verified(self):
        """Gets the is_email_verified of this User.  # noqa: E501


        :return: The is_email_verified of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_email_verified

    @is_email_verified.setter
    def is_email_verified(self, is_email_verified):
        """Sets the is_email_verified of this User.


        :param is_email_verified: The is_email_verified of this User.  # noqa: E501
        :type: bool
        """

        self._is_email_verified = is_email_verified

    @property
    def is_phone_verified(self):
        """Gets the is_phone_verified of this User.  # noqa: E501


        :return: The is_phone_verified of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_phone_verified

    @is_phone_verified.setter
    def is_phone_verified(self, is_phone_verified):
        """Sets the is_phone_verified of this User.


        :param is_phone_verified: The is_phone_verified of this User.  # noqa: E501
        :type: bool
        """

        self._is_phone_verified = is_phone_verified

    @property
    def is_kyc_verified(self):
        """Gets the is_kyc_verified of this User.  # noqa: E501


        :return: The is_kyc_verified of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_kyc_verified

    @is_kyc_verified.setter
    def is_kyc_verified(self, is_kyc_verified):
        """Sets the is_kyc_verified of this User.


        :param is_kyc_verified: The is_kyc_verified of this User.  # noqa: E501
        :type: bool
        """

        self._is_kyc_verified = is_kyc_verified

    @property
    def is_child(self):
        """Gets the is_child of this User.  # noqa: E501


        :return: The is_child of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_child

    @is_child.setter
    def is_child(self, is_child):
        """Sets the is_child of this User.


        :param is_child: The is_child of this User.  # noqa: E501
        :type: bool
        """

        self._is_child = is_child

    @property
    def is_super_user(self):
        """Gets the is_super_user of this User.  # noqa: E501


        :return: The is_super_user of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_super_user

    @is_super_user.setter
    def is_super_user(self, is_super_user):
        """Sets the is_super_user of this User.


        :param is_super_user: The is_super_user of this User.  # noqa: E501
        :type: bool
        """

        self._is_super_user = is_super_user

    @property
    def is_admin(self):
        """Gets the is_admin of this User.  # noqa: E501


        :return: The is_admin of this User.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this User.


        :param is_admin: The is_admin of this User.  # noqa: E501
        :type: bool
        """

        self._is_admin = is_admin

    @property
    def telegram(self):
        """Gets the telegram of this User.  # noqa: E501


        :return: The telegram of this User.  # noqa: E501
        :rtype: TelegramProfile
        """
        return self._telegram

    @telegram.setter
    def telegram(self, telegram):
        """Sets the telegram of this User.


        :param telegram: The telegram of this User.  # noqa: E501
        :type: TelegramProfile
        """

        self._telegram = telegram

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, User):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.api.loans_api import LoansApi  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException


class TestLoansApi(unittest.TestCase):
    """LoansApi unit test stubs"""

    def setUp(self):
        self.api = zarban.wallet.openapi_client.api.loans_api.LoansApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_loan_vault(self):
        """Test case for create_loan_vault

        Create vault  # noqa: E501
        """
        pass

    def test_estimate_loan_collateral(self):
        """Test case for estimate_loan_collateral

        Get collateral and loan amount estimation  # noqa: E501
        """
        pass

    def test_get_all_loan_plans(self):
        """Test case for get_all_loan_plans

        Get all plan loans  # noqa: E501
        """
        pass

    def test_get_loan_details(self):
        """Test case for get_loan_details

        Get loan  # noqa: E501
        """
        pass

    def test_get_user_loans(self):
        """Test case for get_user_loans

        Get user loans  # noqa: E501
        """
        pass

    def test_repay_loan(self):
        """Test case for repay_loan

        Repay Loan  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.service.openapi_client
from zarban.service.openapi_client.api.stable_coin_system_api import StableCoinSystemApi  # noqa: E501
from zarban.service.openapi_client.rest import ApiException


class TestStableCoinSystemApi(unittest.TestCase):
    """StableCoinSystemApi unit test stubs"""

    def setUp(self):
        self.api = zarban.service.openapi_client.api.stable_coin_system_api.StableCoinSystemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_approve_and_join_zar_transaction(self):
        """Test case for approve_and_join_zar_transaction

        approve and join ZAR token into Vat contract  # noqa: E501
        """
        pass

    def test_create_stable_coin_vault(self):
        """Test case for create_stable_coin_vault

        Create vault  # noqa: E501
        """
        pass

    def test_deposit_stable_coin_collateral(self):
        """Test case for deposit_stable_coin_collateral

        Deposit collateral  # noqa: E501
        """
        pass

    def test_exit_gem_transaction(self):
        """Test case for exit_gem_transaction

        exit Gem token (which can be used as collateral) from Vat contract  # noqa: E501
        """
        pass

    def test_exit_zar_transaction(self):
        """Test case for exit_zar_transaction

        exit ZAR token from Vat contract  # noqa: E501
        """
        pass

    def test_get_all_ilks(self):
        """Test case for get_all_ilks

        Get all Ilks  # noqa: E501
        """
        pass

    def test_get_collector_data(self):
        """Test case for get_collector_data

        Get collector data  # noqa: E501
        """
        pass

    def test_get_ilk_by_name(self):
        """Test case for get_ilk_by_name

        Get Ilk by name  # noqa: E501
        """
        pass

    def test_get_vault_by_id(self):
        """Test case for get_vault_by_id

        Get a vault by ID  # noqa: E501
        """
        pass

    def test_get_vault_events_by_id(self):
        """Test case for get_vault_events_by_id

        Get vault events by ID  # noqa: E501
        """
        pass

    def test_get_vaults_by_owner(self):
        """Test case for get_vaults_by_owner

        Get vaults by owner query  # noqa: E501
        """
        pass

    def test_liquidate_vault_transaction(self):
        """Test case for liquidate_vault_transaction

        liquidate a vault  # noqa: E501
        """
        pass

    def test_mint_zar_transaction(self):
        """Test case for mint_zar_transaction

        Mint ZAR  # noqa: E501
        """
        pass

    def test_repay_zar_transaction(self):
        """Test case for repay_zar_transaction

        Repay ZAR  # noqa: E501
        """
        pass

    def test_reset_auction_transaction(self):
        """Test case for reset_auction_transaction

        reset a auction  # noqa: E501
        """
        pass

    def test_take_auction_transaction(self):
        """Test case for take_auction_transaction

        take a auction  # noqa: E501
        """
        pass

    def test_withdraw_collateral_transaction(self):
        """Test case for withdraw_collateral_transaction

        Withdraw collateral  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.user_borrows_response import UserBorrowsResponse  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestUserBorrowsResponse(unittest.TestCase):
    """UserBorrowsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserBorrowsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.user_borrows_response.UserBorrowsResponse()  # noqa: E501
        if include_optional :
            return UserBorrowsResponse(
                data = [
                    zarban.service.openapi_client.models.lendingpool_borrow.LendingpoolBorrow(
                        user = '0', 
                        underlying_asset = zarban.service.openapi_client.models.token.Token(
                            name = 'Zar Stablecoin', 
                            symbol = 'USD', 
                            decimals = 18, 
                            address = '0x1234567890123456789012345678901234567890', 
                            logo_uri = '/assets/logos/dai.svg', 
                            chain_id = 1, 
                            persian_name = 'زر', ), 
                        amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        borrow_rate = '0', 
                        max_borrow_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, )
                    ]
            )
        else :
            return UserBorrowsResponse(
                data = [
                    zarban.service.openapi_client.models.lendingpool_borrow.LendingpoolBorrow(
                        user = '0', 
                        underlying_asset = zarban.service.openapi_client.models.token.Token(
                            name = 'Zar Stablecoin', 
                            symbol = 'USD', 
                            decimals = 18, 
                            address = '0x1234567890123456789012345678901234567890', 
                            logo_uri = '/assets/logos/dai.svg', 
                            chain_id = 1, 
                            persian_name = 'زر', ), 
                        amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        borrow_rate = '0', 
                        max_borrow_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, )
                    ],
        )

    def testUserBorrowsResponse(self):
        """Test UserBorrowsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class Order(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'quote_id': 'str',
        'outputs': 'list[RawDutchAmount]',
        'encoded_order': 'str',
        'signature': 'str',
        'input': 'RawDutchAmount',
        'order_status': 'str',
        'chain_id': 'int',
        'order_hash': 'str',
        'order_type': 'str'
    }

    attribute_map = {
        'quote_id': 'quoteId',
        'outputs': 'outputs',
        'encoded_order': 'encodedOrder',
        'signature': 'signature',
        'input': 'input',
        'order_status': 'orderStatus',
        'chain_id': 'chainId',
        'order_hash': 'orderHash',
        'order_type': 'orderType'
    }

    def __init__(self, quote_id=None, outputs=None, encoded_order=None, signature=None, input=None, order_status=None, chain_id=None, order_hash=None, order_type=None, local_vars_configuration=None):  # noqa: E501
        """Order - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._quote_id = None
        self._outputs = None
        self._encoded_order = None
        self._signature = None
        self._input = None
        self._order_status = None
        self._chain_id = None
        self._order_hash = None
        self._order_type = None
        self.discriminator = None

        if quote_id is not None:
            self.quote_id = quote_id
        self.outputs = outputs
        self.encoded_order = encoded_order
        self.signature = signature
        self.input = input
        self.order_status = order_status
        self.chain_id = chain_id
        self.order_hash = order_hash
        self.order_type = order_type

    @property
    def quote_id(self):
        """Gets the quote_id of this Order.  # noqa: E501


        :return: The quote_id of this Order.  # noqa: E501
        :rtype: str
        """
        return self._quote_id

    @quote_id.setter
    def quote_id(self, quote_id):
        """Sets the quote_id of this Order.


        :param quote_id: The quote_id of this Order.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                quote_id is not None and not re.search(r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$', quote_id)):  # noqa: E501
            raise ValueError(r"Invalid value for `quote_id`, must be a follow pattern or equal to `/^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$/`")  # noqa: E501

        self._quote_id = quote_id

    @property
    def outputs(self):
        """Gets the outputs of this Order.  # noqa: E501


        :return: The outputs of this Order.  # noqa: E501
        :rtype: list[RawDutchAmount]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this Order.


        :param outputs: The outputs of this Order.  # noqa: E501
        :type: list[RawDutchAmount]
        """
        if self.local_vars_configuration.client_side_validation and outputs is None:  # noqa: E501
            raise ValueError("Invalid value for `outputs`, must not be `None`")  # noqa: E501

        self._outputs = outputs

    @property
    def encoded_order(self):
        """Gets the encoded_order of this Order.  # noqa: E501


        :return: The encoded_order of this Order.  # noqa: E501
        :rtype: str
        """
        return self._encoded_order

    @encoded_order.setter
    def encoded_order(self, encoded_order):
        """Sets the encoded_order of this Order.


        :param encoded_order: The encoded_order of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and encoded_order is None:  # noqa: E501
            raise ValueError("Invalid value for `encoded_order`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                encoded_order is not None and not re.search(r'^(0x)?[0-9a-fA-F]*$', encoded_order)):  # noqa: E501
            raise ValueError(r"Invalid value for `encoded_order`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]*$/`")  # noqa: E501

        self._encoded_order = encoded_order

    @property
    def signature(self):
        """Gets the signature of this Order.  # noqa: E501


        :return: The signature of this Order.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this Order.


        :param signature: The signature of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signature is None:  # noqa: E501
            raise ValueError("Invalid value for `signature`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                signature is not None and not re.search(r'^(0x)?[0-9a-fA-F]{130}$', signature)):  # noqa: E501
            raise ValueError(r"Invalid value for `signature`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{130}$/`")  # noqa: E501

        self._signature = signature

    @property
    def input(self):
        """Gets the input of this Order.  # noqa: E501


        :return: The input of this Order.  # noqa: E501
        :rtype: RawDutchAmount
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this Order.


        :param input: The input of this Order.  # noqa: E501
        :type: RawDutchAmount
        """
        if self.local_vars_configuration.client_side_validation and input is None:  # noqa: E501
            raise ValueError("Invalid value for `input`, must not be `None`")  # noqa: E501

        self._input = input

    @property
    def order_status(self):
        """Gets the order_status of this Order.  # noqa: E501


        :return: The order_status of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_status

    @order_status.setter
    def order_status(self, order_status):
        """Sets the order_status of this Order.


        :param order_status: The order_status of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_status is None:  # noqa: E501
            raise ValueError("Invalid value for `order_status`, must not be `None`")  # noqa: E501
        allowed_values = ["open", "expired", "error", "cancelled", "filled", "insufficient-funds"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and order_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `order_status` ({0}), must be one of {1}"  # noqa: E501
                .format(order_status, allowed_values)
            )

        self._order_status = order_status

    @property
    def chain_id(self):
        """Gets the chain_id of this Order.  # noqa: E501


        :return: The chain_id of this Order.  # noqa: E501
        :rtype: int
        """
        return self._chain_id

    @chain_id.setter
    def chain_id(self, chain_id):
        """Sets the chain_id of this Order.


        :param chain_id: The chain_id of this Order.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and chain_id is None:  # noqa: E501
            raise ValueError("Invalid value for `chain_id`, must not be `None`")  # noqa: E501

        self._chain_id = chain_id

    @property
    def order_hash(self):
        """Gets the order_hash of this Order.  # noqa: E501


        :return: The order_hash of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_hash

    @order_hash.setter
    def order_hash(self, order_hash):
        """Sets the order_hash of this Order.


        :param order_hash: The order_hash of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `order_hash`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                order_hash is not None and not re.search(r'^(0x)?[0-9a-fA-F]{64}$', order_hash)):  # noqa: E501
            raise ValueError(r"Invalid value for `order_hash`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{64}$/`")  # noqa: E501

        self._order_hash = order_hash

    @property
    def order_type(self):
        """Gets the order_type of this Order.  # noqa: E501


        :return: The order_type of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_type

    @order_type.setter
    def order_type(self, order_type):
        """Sets the order_type of this Order.


        :param order_type: The order_type of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_type is None:  # noqa: E501
            raise ValueError("Invalid value for `order_type`, must not be `None`")  # noqa: E501
        allowed_values = ["dutch", "limit"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and order_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `order_type` ({0}), must be one of {1}"  # noqa: E501
                .format(order_type, allowed_values)
            )

        self._order_type = order_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Order):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class QuoteRequestOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'dry_run': 'bool',
        'slippage_tolerance': 'str',
        'use_synthetic_quotes': 'bool',
        'permit_signature': 'str',
        'permit_nonce': 'str',
        'permit_expiration': 'int',
        'permit_amount': 'str',
        'permit_sig_deadline': 'int',
        'quote_id': 'str',
        'encoded_order': 'str'
    }

    attribute_map = {
        'dry_run': 'dryRun',
        'slippage_tolerance': 'slippageTolerance',
        'use_synthetic_quotes': 'useSyntheticQuotes',
        'permit_signature': 'permitSignature',
        'permit_nonce': 'permitNonce',
        'permit_expiration': 'permitExpiration',
        'permit_amount': 'permitAmount',
        'permit_sig_deadline': 'permitSigDeadline',
        'quote_id': 'quoteId',
        'encoded_order': 'encodedOrder'
    }

    def __init__(self, dry_run=False, slippage_tolerance='0.005', use_synthetic_quotes=False, permit_signature=None, permit_nonce=None, permit_expiration=None, permit_amount=None, permit_sig_deadline=None, quote_id=None, encoded_order=None, local_vars_configuration=None):  # noqa: E501
        """QuoteRequestOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._dry_run = None
        self._slippage_tolerance = None
        self._use_synthetic_quotes = None
        self._permit_signature = None
        self._permit_nonce = None
        self._permit_expiration = None
        self._permit_amount = None
        self._permit_sig_deadline = None
        self._quote_id = None
        self._encoded_order = None
        self.discriminator = None

        if dry_run is not None:
            self.dry_run = dry_run
        if slippage_tolerance is not None:
            self.slippage_tolerance = slippage_tolerance
        if use_synthetic_quotes is not None:
            self.use_synthetic_quotes = use_synthetic_quotes
        if permit_signature is not None:
            self.permit_signature = permit_signature
        if permit_nonce is not None:
            self.permit_nonce = permit_nonce
        if permit_expiration is not None:
            self.permit_expiration = permit_expiration
        if permit_amount is not None:
            self.permit_amount = permit_amount
        if permit_sig_deadline is not None:
            self.permit_sig_deadline = permit_sig_deadline
        if quote_id is not None:
            self.quote_id = quote_id
        if encoded_order is not None:
            self.encoded_order = encoded_order

    @property
    def dry_run(self):
        """Gets the dry_run of this QuoteRequestOptions.  # noqa: E501


        :return: The dry_run of this QuoteRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._dry_run

    @dry_run.setter
    def dry_run(self, dry_run):
        """Sets the dry_run of this QuoteRequestOptions.


        :param dry_run: The dry_run of this QuoteRequestOptions.  # noqa: E501
        :type: bool
        """

        self._dry_run = dry_run

    @property
    def slippage_tolerance(self):
        """Gets the slippage_tolerance of this QuoteRequestOptions.  # noqa: E501


        :return: The slippage_tolerance of this QuoteRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._slippage_tolerance

    @slippage_tolerance.setter
    def slippage_tolerance(self, slippage_tolerance):
        """Sets the slippage_tolerance of this QuoteRequestOptions.


        :param slippage_tolerance: The slippage_tolerance of this QuoteRequestOptions.  # noqa: E501
        :type: str
        """

        self._slippage_tolerance = slippage_tolerance

    @property
    def use_synthetic_quotes(self):
        """Gets the use_synthetic_quotes of this QuoteRequestOptions.  # noqa: E501


        :return: The use_synthetic_quotes of this QuoteRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._use_synthetic_quotes

    @use_synthetic_quotes.setter
    def use_synthetic_quotes(self, use_synthetic_quotes):
        """Sets the use_synthetic_quotes of this QuoteRequestOptions.


        :param use_synthetic_quotes: The use_synthetic_quotes of this QuoteRequestOptions.  # noqa: E501
        :type: bool
        """

        self._use_synthetic_quotes = use_synthetic_quotes

    @property
    def permit_signature(self):
        """Gets the permit_signature of this QuoteRequestOptions.  # noqa: E501


        :return: The permit_signature of this QuoteRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._permit_signature

    @permit_signature.setter
    def permit_signature(self, permit_signature):
        """Sets the permit_signature of this QuoteRequestOptions.


        :param permit_signature: The permit_signature of this QuoteRequestOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                permit_signature is not None and not re.search(r'^(0x)?[0-9a-fA-F]{130}$', permit_signature)):  # noqa: E501
            raise ValueError(r"Invalid value for `permit_signature`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{130}$/`")  # noqa: E501

        self._permit_signature = permit_signature

    @property
    def permit_nonce(self):
        """Gets the permit_nonce of this QuoteRequestOptions.  # noqa: E501


        :return: The permit_nonce of this QuoteRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._permit_nonce

    @permit_nonce.setter
    def permit_nonce(self, permit_nonce):
        """Sets the permit_nonce of this QuoteRequestOptions.


        :param permit_nonce: The permit_nonce of this QuoteRequestOptions.  # noqa: E501
        :type: str
        """

        self._permit_nonce = permit_nonce

    @property
    def permit_expiration(self):
        """Gets the permit_expiration of this QuoteRequestOptions.  # noqa: E501


        :return: The permit_expiration of this QuoteRequestOptions.  # noqa: E501
        :rtype: int
        """
        return self._permit_expiration

    @permit_expiration.setter
    def permit_expiration(self, permit_expiration):
        """Sets the permit_expiration of this QuoteRequestOptions.


        :param permit_expiration: The permit_expiration of this QuoteRequestOptions.  # noqa: E501
        :type: int
        """

        self._permit_expiration = permit_expiration

    @property
    def permit_amount(self):
        """Gets the permit_amount of this QuoteRequestOptions.  # noqa: E501


        :return: The permit_amount of this QuoteRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._permit_amount

    @permit_amount.setter
    def permit_amount(self, permit_amount):
        """Sets the permit_amount of this QuoteRequestOptions.


        :param permit_amount: The permit_amount of this QuoteRequestOptions.  # noqa: E501
        :type: str
        """

        self._permit_amount = permit_amount

    @property
    def permit_sig_deadline(self):
        """Gets the permit_sig_deadline of this QuoteRequestOptions.  # noqa: E501


        :return: The permit_sig_deadline of this QuoteRequestOptions.  # noqa: E501
        :rtype: int
        """
        return self._permit_sig_deadline

    @permit_sig_deadline.setter
    def permit_sig_deadline(self, permit_sig_deadline):
        """Sets the permit_sig_deadline of this QuoteRequestOptions.


        :param permit_sig_deadline: The permit_sig_deadline of this QuoteRequestOptions.  # noqa: E501
        :type: int
        """

        self._permit_sig_deadline = permit_sig_deadline

    @property
    def quote_id(self):
        """Gets the quote_id of this QuoteRequestOptions.  # noqa: E501


        :return: The quote_id of this QuoteRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._quote_id

    @quote_id.setter
    def quote_id(self, quote_id):
        """Sets the quote_id of this QuoteRequestOptions.


        :param quote_id: The quote_id of this QuoteRequestOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                quote_id is not None and not re.search(r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$', quote_id)):  # noqa: E501
            raise ValueError(r"Invalid value for `quote_id`, must be a follow pattern or equal to `/^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$/`")  # noqa: E501

        self._quote_id = quote_id

    @property
    def encoded_order(self):
        """Gets the encoded_order of this QuoteRequestOptions.  # noqa: E501


        :return: The encoded_order of this QuoteRequestOptions.  # noqa: E501
        :rtype: str
        """
        return self._encoded_order

    @encoded_order.setter
    def encoded_order(self, encoded_order):
        """Sets the encoded_order of this QuoteRequestOptions.


        :param encoded_order: The encoded_order of this QuoteRequestOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                encoded_order is not None and not re.search(r'^(0x)?[0-9a-fA-F]*$', encoded_order)):  # noqa: E501
            raise ValueError(r"Invalid value for `encoded_order`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]*$/`")  # noqa: E501

        self._encoded_order = encoded_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuoteRequestOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuoteRequestOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.balance import Balance  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestBalance(unittest.TestCase):
    """Balance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Balance
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.balance.Balance()  # noqa: E501
        if include_optional :
            return Balance(
                locked = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                coin = zarban.wallet.openapi_client.models.coin.Coin(
                    config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                        is_tradeable = True, 
                        withdraw_fees = {"tron":"10"}, 
                        min_withdrawal = {"tron":"10"}, 
                        needs_memo = True, ), 
                    symbol = 'USD', 
                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                    logo_uri = '0', 
                    depositable_networks = [
                        zarban.wallet.openapi_client.models.network.Network(
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', )
                        ], 
                    withdrawable_networks = [
                        zarban.wallet.openapi_client.models.network.Network(
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', )
                        ], 
                    content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                        title = '0', 
                        text = '0', 
                        bullets = [
                            '0'
                            ], ), ), 
                balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}
            )
        else :
            return Balance(
                locked = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}},
                coin = zarban.wallet.openapi_client.models.coin.Coin(
                    config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                        is_tradeable = True, 
                        withdraw_fees = {"tron":"10"}, 
                        min_withdrawal = {"tron":"10"}, 
                        needs_memo = True, ), 
                    symbol = 'USD', 
                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                    logo_uri = '0', 
                    depositable_networks = [
                        zarban.wallet.openapi_client.models.network.Network(
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', )
                        ], 
                    withdrawable_networks = [
                        zarban.wallet.openapi_client.models.network.Network(
                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                            logo_uri = '0', )
                        ], 
                    content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                        title = '0', 
                        text = '0', 
                        bullets = [
                            '0'
                            ], ), ),
                balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}},
        )

    def testBalance(self):
        """Test Balance"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
